@@ -11,10 +11,11 @@
 #include <zypp/ZConfig.h>
 #include <zypp/TmpPath.h>
 #include <zypp-core/zyppng/pipelines/Wait>
-#include <zypp-core/zyppng/rpc/zerocopystreams.h>
 #include <zypp-core/zyppng/base/private/linuxhelpers_p.h>
 
-#include <zypp-proto/test/tvm.pb.h>
+#include <yaml-cpp/yaml.h>
+#include <shared/tvm/tvmsettings.h>
+
 #include <iostream>
 #include <fstream>
 
@@ -137,7 +138,7 @@ BOOST_AUTO_TEST_CASE( http_attach_prov )
   auto op = prov->attachMedia( web.url(), zyppng::ProvideMediaSpec( "OnlineMedia" )
                                                .setMediaFile( webRoot / "media.1" / "media" )
                                                .setMedianr(1) )
-            | mbind ( [&]( zyppng::Provide::MediaHandle &&res ){
+            | and_then ( [&]( zyppng::Provide::MediaHandle &&res ){
               media = std::move(res);
               return prov->provide( media, "/test.txt", zyppng::ProvideFileSpec() );
             });
@@ -186,7 +187,7 @@ BOOST_AUTO_TEST_CASE( http_attach_prov_404 )
   auto op = prov->attachMedia( web.url(), zyppng::ProvideMediaSpec( "OnlineMedia" )
                                                .setMediaFile( webRoot / "media.1" / "media" )
                                                .setMedianr(1) )
-            | mbind ( [&]( zyppng::Provide::MediaHandle &&res ){
+            | and_then ( [&]( zyppng::Provide::MediaHandle &&res ){
               media = std::move(res);
               return prov->provide( media, "/doesnotexist", zyppng::ProvideFileSpec() );
             });
@@ -235,7 +236,7 @@ BOOST_AUTO_TEST_CASE( http_attach_prov_notafile )
   auto op = prov->attachMedia( web.url(), zyppng::ProvideMediaSpec( "OnlineMedia" )
                                                .setMediaFile( webRoot / "media.1" / "media" )
                                                .setMedianr(1) )
-            | mbind ( [&]( zyppng::Provide::MediaHandle &&res ){
+            | and_then ( [&]( zyppng::Provide::MediaHandle &&res ){
               media = std::move(res);
               return prov->provide( media, "/media.1", zyppng::ProvideFileSpec() );
             });
@@ -540,7 +541,7 @@ BOOST_AUTO_TEST_CASE( http_attach_prov_auth )
   auto op = prov->attachMedia( baseUrl, zyppng::ProvideMediaSpec( "OnlineMedia" )
                                                .setMediaFile( webRoot / "media.1" / "media" )
                                                .setMedianr(1) )
-            | mbind ( [&]( zyppng::Provide::MediaHandle &&res ){
+            | and_then ( [&]( zyppng::Provide::MediaHandle &&res ){
               media = std::move(res);
               return prov->provide( media, "/test.txt", zyppng::ProvideFileSpec() );
             });
@@ -567,19 +568,28 @@ BOOST_AUTO_TEST_CASE( http_attach_prov_auth )
   BOOST_REQUIRE_EQUAL( sum, std::string("7e562d52c100b68e9d6a561fa8519575") );
 }
 
-static void writeTVMConfig ( const zypp::Pathname &file, const zypp::proto::test::TVMSettings &set )
+static void writeTVMConfig ( const zypp::Pathname &file, const zypp::test::TVMSettings &set )
 {
-  const auto &fname = file/"tvm.conf";
-  int fd = open( fname.asString().data(), O_WRONLY | O_CREAT | O_TRUNC, 0666 );
-  if ( fd < 0 ) {
-    ERR << "Failed to open/create file " << fname << " error: "<<zyppng::strerr_cxx(errno)<< " " << errno << std::endl;
+  try {
+    YAML::Emitter yOut;
+    yOut << YAML::convert<zypp::test::TVMSettings>::encode( set );
+
+    const auto &fname = file/"tvm.conf";
+    std::ofstream fout( fname.asString() );
+    fout << yOut.c_str();
+
+    MIL << "TVM config serialized to: " << fname << std::endl;
+
+  }  catch ( YAML::Exception &e ) {
+    WAR << "YAML exception when serializing the control file: " << e.what() << std::endl;
+    return;
+  } catch ( const std::exception &e )  {
+    WAR << "Error when serializing the control file: " << e.what() << std::endl;
+    return;
+  } catch ( ... )  {
+    WAR << "Unknown error when serializing the control file" << std::endl;
     return;
   }
-  zyppng::FileOutputStream out( fd );
-  out.SetCloseOnDelete( true );
-  if ( !set.SerializeToZeroCopyStream( &out ) )
-    ERR << "Failed to serialize settings" << std::endl;
-  MIL << "TVM config serialized to: " << fname << std::endl;
 }
 
 static auto makeDVDProv ( zyppng::ProvideRef &prov, const zypp::filesystem::Pathname &devRoot, int mediaNr, const std::string &fName )
@@ -641,16 +651,25 @@ BOOST_AUTO_TEST_CASE( tvm_basic )
   auto prov = zyppng::Provide::create ( provideRoot );
   prov->setWorkerPath ( workerPath );
 
-  zypp::proto::test::TVMSettings devSet;
-  auto dev = devSet.add_devices();
-  dev->set_name("/fakedev/tvm/slot1");
-  dev->set_insertedpath( (devRoot/"cd1").asString() );
-  dev = devSet.add_devices();
-  dev->set_name("/fakedev/tvm/slot2");
-  dev->set_insertedpath( (devRoot/"cd2").asString() );
-  dev = devSet.add_devices();
-  dev->set_name("/fakedev/tvm/slot3");
-  dev->set_insertedpath( (devRoot/"cd3").asString() );
+  zypp::test::TVMSettings devSet;
+  devSet.devices.push_back(
+    zypp::test::TVMSettings::Device{
+      .name = "/fakedev/tvm/slot1",
+      .insertedPath = (devRoot/"cd1").asString()
+    }
+  );
+  devSet.devices.push_back(
+    zypp::test::TVMSettings::Device{
+      .name = "/fakedev/tvm/slot2",
+      .insertedPath = (devRoot/"cd2").asString()
+    }
+  );
+  devSet.devices.push_back(
+    zypp::test::TVMSettings::Device{
+      .name = "/fakedev/tvm/slot3",
+      .insertedPath = (devRoot/"cd3").asString()
+    }
+  );
   writeTVMConfig( provideRoot, devSet );
 
   prov->start();
@@ -661,7 +680,7 @@ BOOST_AUTO_TEST_CASE( tvm_basic )
   ops.push_back( makeDVDProv( prov, devRoot, 2, "/file2") );
   ops.push_back( makeDVDProv( prov, devRoot, 3, "/file3") );
 
-  auto r = std::move(ops) | zyppng::waitFor<zyppng::expected<void>>();
+  auto r = std::move(ops) | zyppng::waitFor();
   r->sigReady().connect([&](){
     ev->quit();
   });
@@ -690,14 +709,25 @@ BOOST_AUTO_TEST_CASE( tvm_medchange )
   auto prov = zyppng::Provide::create ( provideRoot );
   prov->setWorkerPath ( workerPath );
 
-  zypp::proto::test::TVMSettings devSet;
-  auto dev = devSet.add_devices();
-  dev->set_name("/fakedev/tvm/slot1");
-  dev->set_insertedpath( (devRoot/"cd1").asString() );
-  dev = devSet.add_devices();
-  dev->set_name("/fakedev/tvm/slot2");
-  dev = devSet.add_devices();
-  dev->set_name("/fakedev/tvm/slot3");
+  zypp::test::TVMSettings devSet;
+  devSet.devices.push_back(
+    zypp::test::TVMSettings::Device{
+      .name = "/fakedev/tvm/slot1",
+      .insertedPath = (devRoot/"cd1").asString()
+    }
+  );
+  devSet.devices.push_back(
+    zypp::test::TVMSettings::Device{
+      .name = "/fakedev/tvm/slot2",
+      .insertedPath = ""
+    }
+  );
+  devSet.devices.push_back(
+    zypp::test::TVMSettings::Device{
+      .name = "/fakedev/tvm/slot3",
+      .insertedPath = ""
+    }
+  );
   writeTVMConfig( provideRoot, devSet );
 
   prov->start();
@@ -711,7 +741,7 @@ BOOST_AUTO_TEST_CASE( tvm_medchange )
     freeDevices = devices;
     labelAsked = label;
     mediaNrAsked = mediaNr;
-    devSet.mutable_devices(1)->set_insertedpath( (devRoot/"cd2").asString() );
+    devSet.devices[1].insertedPath = (devRoot/"cd2").asString();
     writeTVMConfig( provideRoot, devSet );
     return zyppng::Provide::RETRY;
   });
@@ -721,7 +751,7 @@ BOOST_AUTO_TEST_CASE( tvm_medchange )
   ops.push_back( makeDVDProv( prov, devRoot, 1, "/file1") );
   ops.push_back( makeDVDProv( prov, devRoot, 2, "/file2") );
 
-  auto r = std::move(ops) | zyppng::waitFor<zyppng::expected<void>>();
+  auto r = std::move(ops) | zyppng::waitFor();
   r->sigReady().connect([&](){
     ev->quit();
   });
@@ -757,14 +787,25 @@ BOOST_DATA_TEST_CASE( tvm_medchange_abort, bdata::make( cancelOps ), cancelOp )
   auto prov = zyppng::Provide::create ( provideRoot );
   prov->setWorkerPath ( workerPath );
 
-  zypp::proto::test::TVMSettings devSet;
-  auto dev = devSet.add_devices();
-  dev->set_name("/fakedev/tvm/slot1");
-  dev->set_insertedpath( (devRoot/"cd1").asString() );
-  dev = devSet.add_devices();
-  dev->set_name("/fakedev/tvm/slot2");
-  dev = devSet.add_devices();
-  dev->set_name("/fakedev/tvm/slot3");
+  zypp::test::TVMSettings devSet;
+  devSet.devices.push_back(
+    zypp::test::TVMSettings::Device{
+      .name = "/fakedev/tvm/slot1",
+      .insertedPath = (devRoot/"cd1").asString()
+    }
+  );
+  devSet.devices.push_back(
+    zypp::test::TVMSettings::Device{
+      .name = "/fakedev/tvm/slot2",
+      .insertedPath = ""
+    }
+  );
+  devSet.devices.push_back(
+    zypp::test::TVMSettings::Device{
+      .name = "/fakedev/tvm/slot3",
+      .insertedPath = ""
+    }
+  );
   writeTVMConfig( provideRoot, devSet );
 
   prov->start();
@@ -833,10 +874,13 @@ BOOST_AUTO_TEST_CASE( tvm_jammed )
     return zyppng::Provide::ABORT;
   });
 
-  zypp::proto::test::TVMSettings devSet;
-  auto dev = devSet.add_devices();
-  dev->set_name("/fakedev/tvm/slot1");
-  dev->set_insertedpath( (devRoot/"cd1").asString() );
+  zypp::test::TVMSettings devSet;
+  devSet.devices.push_back(
+    zypp::test::TVMSettings::Device{
+      .name = "/fakedev/tvm/slot1",
+      .insertedPath = (devRoot/"cd1").asString()
+    }
+  );
   writeTVMConfig( provideRoot, devSet );
 
   prov->start();
@@ -888,7 +932,7 @@ BOOST_AUTO_TEST_CASE( tvm_jammed_release )
   auto prov = zyppng::Provide::create ( provideRoot );
   prov->setWorkerPath ( workerPath );
 
-  zypp::proto::test::TVMSettings devSet;
+  zypp::test::TVMSettings devSet;
 
   bool mediaChangeAllowed = false;
   bool gotInvalidMediaChange = false;
@@ -898,14 +942,17 @@ BOOST_AUTO_TEST_CASE( tvm_jammed_release )
       return zyppng::Provide::ABORT;
     }
 
-    devSet.mutable_devices(0)->set_insertedpath( (devRoot/"cd2").asString() );
+    devSet.devices[0].insertedPath = (devRoot/"cd2").asString();
     writeTVMConfig( provideRoot, devSet );
     return zyppng::Provide::RETRY;
   });
 
-  auto dev = devSet.add_devices();
-  dev->set_name("/fakedev/tvm/slot1");
-  dev->set_insertedpath( (devRoot/"cd1").asString() );
+  devSet.devices.push_back(
+    zypp::test::TVMSettings::Device{
+      .name = "/fakedev/tvm/slot1",
+      .insertedPath = (devRoot/"cd1").asString()
+    }
+  );
   writeTVMConfig( provideRoot, devSet );
 
   prov->start();
