@@ -51,7 +51,7 @@ namespace zypp
     /////////////////////////////////////////////////////////////////
 
     /** lsof output line + files extracted so far for this PID */
-    typedef std::pair<std::string,std::unordered_set<std::string>> CacheEntry;
+    using CacheEntry = std::pair<std::string, std::unordered_set<std::string>>;
 
     /////////////////////////////////////////////////////////////////
     /// \class FilterRunsInContainer
@@ -182,8 +182,15 @@ namespace zypp
         TmpUnblock()
         : _wasBlocked( librpmDb::isBlocked() )
         { if ( _wasBlocked ) librpmDb::unblockAccess(); }
-        ~TmpUnblock()
-        { if ( _wasBlocked ) librpmDb::blockAccess(); }
+        TmpUnblock(const TmpUnblock &) = delete;
+        TmpUnblock(TmpUnblock &&) = delete;
+        TmpUnblock &operator=(const TmpUnblock &) = delete;
+        TmpUnblock &operator=(TmpUnblock &&) = delete;
+        ~TmpUnblock() {
+          if (_wasBlocked)
+            librpmDb::blockAccess();
+        }
+
       private:
         bool _wasBlocked;
       } tmpUnblock;
@@ -544,7 +551,7 @@ namespace zypp
     str::smatch what;
     std::string ret;
     iostr::simpleParseFile( InputStream( Pathname("/proc")/pid/"cgroup" ),
-                            [&]( int num_r, std::string line_r )->bool
+                            [&]( int num_r, const std::string& line_r )->bool
                             {
                               if ( str::regex_match( line_r, what, rx ) )
                               {
