@@ -54,10 +54,10 @@ namespace zypp
     /// If variable is unset or empty nothing is substituted.
     /// Otherwise, the expansion of \c word is substituted.</li>
     /// </ul>
-    struct RepoVarExpand
+    struct ZYPP_API RepoVarExpand
     {
       /** Function taking a variable name and returning a pointer to the variable value or \c nullptr if unset. */
-      typedef function<const std::string * ( const std::string & )> VarRetriever;
+      using VarRetriever = function<const std::string *(const std::string &)>;
 
       /** Return a copy of \a value_r with embedded variables expanded. */
       std::string operator()( const std::string & value_r, VarRetriever varRetriever_r ) const;
@@ -102,7 +102,7 @@ namespace zypp
      *
      * \see \ref RepoVarExpand for supported variable syntax.
      */
-    struct RepoVariablesStringReplacer
+    struct ZYPP_TESTS RepoVariablesStringReplacer
     {
       std::string operator()( const std::string & value_r ) const;
 
@@ -116,7 +116,7 @@ namespace zypp
      * Replaces repository variables in the URL (except for user/pass inside authority)
      * \see RepoVariablesStringReplacer
      */
-    struct RepoVariablesUrlReplacer
+    struct ZYPP_API RepoVariablesUrlReplacer
     {
       Url operator()( const Url & url_r ) const;
     };
@@ -124,16 +124,16 @@ namespace zypp
   ///////////////////////////////////////////////////////////////////
 
   /** \relates RepoVariablesStringReplacer Helper managing repo variables replaced strings */
-  typedef base::ValueTransform<std::string, repo::RepoVariablesStringReplacer> RepoVariablesReplacedString;
+  using RepoVariablesReplacedString = base::ValueTransform<std::string, repo::RepoVariablesStringReplacer>;
 
   /** \relates RepoVariablesStringReplacer Helper managing repo variables replaced string lists */
-  typedef base::ContainerTransform<std::list<std::string>, repo::RepoVariablesStringReplacer> RepoVariablesReplacedStringList;
+  using RepoVariablesReplacedStringList = base::ContainerTransform<std::list<std::string>, repo::RepoVariablesStringReplacer>;
 
   /** \relates RepoVariablesUrlReplacer Helper managing repo variables replaced urls */
-  typedef base::ValueTransform<Url, repo::RepoVariablesUrlReplacer> RepoVariablesReplacedUrl;
+  using RepoVariablesReplacedUrl = base::ValueTransform<Url, repo::RepoVariablesUrlReplacer>;
 
   /** \relates RepoVariablesUrlReplacer Helper managing repo variables replaced url lists */
-  typedef base::ContainerTransform<std::list<Url>, repo::RepoVariablesUrlReplacer> RepoVariablesReplacedUrlList;
+  using RepoVariablesReplacedUrlList = base::ContainerTransform<std::list<Url>, repo::RepoVariablesUrlReplacer>;
 
 } // namespace zypp
 ///////////////////////////////////////////////////////////////////
