@@ -50,10 +50,10 @@ namespace zypp
     /// packages as an own kind of solvable and map their arch to
     /// \ref Arch_noarch.
     ///////////////////////////////////////////////////////////////////
-    class Solvable : protected detail::PoolMember
+    class ZYPP_API Solvable : protected detail::PoolMember
     {
     public:
-      typedef sat::detail::SolvableIdType IdType;
+      using IdType = sat::detail::SolvableIdType;
 
       static const IdString retractedToken;	///< Indicator provides `retracted-patch-package()`
       static const IdString ptfMasterToken;	///< Indicator provides `ptf()`
@@ -65,6 +65,11 @@ namespace zypp
       : _id( detail::noSolvableId )
       {}
 
+      Solvable(const Solvable &) = default;
+      Solvable(Solvable &&) noexcept = default;
+      Solvable &operator=(const Solvable &) = default;
+      Solvable &operator=(Solvable &&) noexcept = default;
+
       /** \ref PoolImpl ctor. */
       explicit Solvable( IdType id_r )
       : _id( id_r )
@@ -433,13 +438,13 @@ namespace zypp
     ///////////////////////////////////////////////////////////////////
 
     /** \relates Solvable Stream output */
-    std::ostream & operator<<( std::ostream & str, const Solvable & obj );
+    std::ostream & operator<<( std::ostream & str, const Solvable & obj ) ZYPP_API;
 
     /** \relates Solvable More verbose stream output including dependencies */
-    std::ostream & dumpOn( std::ostream & str, const Solvable & obj );
+    std::ostream & dumpOn( std::ostream & str, const Solvable & obj ) ZYPP_API;
 
     /** \relates Solvable XML output */
-    std::ostream & dumpAsXmlOn( std::ostream & str, const Solvable & obj );
+    std::ostream & dumpAsXmlOn( std::ostream & str, const Solvable & obj ) ZYPP_API;
 
     /** \relates Solvable */
     inline bool operator==( const Solvable & lhs, const Solvable & rhs )
@@ -558,9 +563,9 @@ namespace zypp
      * \relates Solvable
      * \relates sat::SolvIterMixin
      */
-    struct asSolvable
+    struct ZYPP_TESTS asSolvable
     {
-      typedef Solvable result_type;
+      using result_type = Solvable;
 
       Solvable operator()( const Solvable & solv_r ) const
       { return solv_r; }
